Module memory

Module memory 

Structs

DeviceMemSchema
This struct represent a memory schema for node output memory that are handled by a GPU.
DeviceMemoryPool
DeviceResolvedMemSchema
This struct represents a resolved memory schema for a model that contains GPU operators. This schema is concrete.