Module sync

Module sync 

Structs

DeviceSync

Enums

DeviceSyncKind

Functions

sync_inputs_if_required
Map node inputs through the translation mapping, inserting DeviceSync nodes where needed to move tensors to/from the device.
sync_model_outputs_if_required
For model outputs that are on device, insert DeviceSync nodes to move them back to host.