pub struct OwnedDeviceTensor {
pub inner: DValue,
pub device_buffer: Box<dyn DeviceBuffer>,
}Expand description
This struct represents a owned tensor that can be accessed from the GPU and the CPU.
Fields
inner: DValuedevice_buffer: Box<dyn DeviceBuffer>Implementations
Sourceimpl OwnedDeviceTensor
impl OwnedDeviceTensor
Sourcepub fn from_tensor<T: Into<DValue>>(tensor: T) -> TractResult<Self>
pub fn from_tensor<T: Into<DValue>>(tensor: T) -> TractResult<Self>
Create a owned gpu tensor from a cpu tensor.
pub fn shape(&self) -> &[usize]
Sourcepub fn device_buffer(&self) -> &dyn DeviceBuffer
pub fn device_buffer(&self) -> &dyn DeviceBuffer
Get underlying inner device buffer.
pub fn device_buffer_ptr(&self) -> *const c_void
Sourcepub fn buffer_offset<I: Copy + 'static>(&self) -> Iwhere
usize: AsPrimitive<I>,
pub fn buffer_offset<I: Copy + 'static>(&self) -> Iwhere
usize: AsPrimitive<I>,
Get underlying inner buffer offset
Sourcepub fn reshaped(&self, shape: impl Into<TVec<usize>>) -> TractResult<Self>
pub fn reshaped(&self, shape: impl Into<TVec<usize>>) -> TractResult<Self>
Reshaped tensor with given shape.
Sourcepub fn restrided(&self, strides: impl Into<TVec<isize>>) -> TractResult<Self>
pub fn restrided(&self, strides: impl Into<TVec<isize>>) -> TractResult<Self>
Change tensor stride.
Sourcepub unsafe fn reshaped_with_geometry_unchecked(
&self,
shape: impl Into<TVec<usize>>,
strides: impl Into<TVec<isize>>,
) -> Self
pub unsafe fn reshaped_with_geometry_unchecked( &self, shape: impl Into<TVec<usize>>, strides: impl Into<TVec<isize>>, ) -> Self
Reshaped tensor with given shape and strides, no consistency check.
pub fn view(&self) -> TensorView<'_>