OwnedDeviceTensor

Trait OwnedDeviceTensor 

pub trait OwnedDeviceTensor:
    Downcast
    + DynClone
    + Send
    + Sync
    + Debug
    + DynEq {
    // Required methods
    fn datum_type(&self) -> DatumType;
    fn shape(&self) -> &[usize];
    fn strides(&self) -> &[isize];
    fn reshaped(&self, shape: TVec<usize>) -> TractResult<DeviceTensor>;
    fn restrided(&self, shape: TVec<isize>) -> TractResult<DeviceTensor>;
    fn exotic_fact(&self) -> Option<&dyn ExoticFact>;
    fn get_bytes_slice(&self, offset: usize, len: usize) -> Vec<u8> ;
    fn device_buffer(&self) -> &dyn DeviceBuffer;
    fn to_host(&self) -> TractResult<Arc<Tensor>>;

    // Provided method
    fn len(&self) -> usize { ... }
}

Required Methods

fn datum_type(&self) -> DatumType

fn shape(&self) -> &[usize]

fn strides(&self) -> &[isize]

fn reshaped(&self, shape: TVec<usize>) -> TractResult<DeviceTensor>

fn restrided(&self, shape: TVec<isize>) -> TractResult<DeviceTensor>

fn exotic_fact(&self) -> Option<&dyn ExoticFact>

fn get_bytes_slice(&self, offset: usize, len: usize) -> Vec<u8>

fn device_buffer(&self) -> &dyn DeviceBuffer

fn to_host(&self) -> TractResult<Arc<Tensor>>

Provided Methods

fn len(&self) -> usize

Implementations

Source

impl dyn OwnedDeviceTensor

pub fn is<__T: OwnedDeviceTensor>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: OwnedDeviceTensor>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: OwnedDeviceTensor>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: OwnedDeviceTensor>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: OwnedDeviceTensor>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.