Module turn_handler

Module turn_handler 

Structs

DeviceTurnHandler

Functions

make_scalar_exotic_tensor_for_node
make_tensor_for_node
make_tensor_for_node_output
Like make_tensor_for_node but for one output slot of a multi-output node: the memory schema reserves one arena region per device output.