BroadcastKind

Enum BroadcastKind 

pub enum BroadcastKind {
    Unicast,
    ByScalarLeft,
    ByScalarRight,
    Nd1,
    Nd2,
    Nd3,
    Nd4,
    Nd5,
    Nd6,
}

Variants



Unicast



ByScalarLeft



ByScalarRight



Nd1



Nd2



Nd3



Nd4



Nd5



Nd6

Implementations

Source

impl BroadcastKind

pub const ALL: [BroadcastKind; 8]

pub fn from_rank(rank: usize) -> TractResult<Self>

pub fn name(&self) -> &'static str

pub fn copy_tname(dt: DatumType) -> &'static str

Map datum type to the copy kernel type name based on element size. Copy kernels only care about element size, not the actual type.

pub fn copy_kernel_name( &self, dt: DatumType, prefix: &str, ) -> TractResult<String>

pub fn all_copy_kernel_names(prefix: &str) -> Vec<String>