pub trait DeviceContext:
Downcast
+ DynClone
+ Send
+ Sync {
// Required methods
fn tensor_to_device(
&self,
tensor: TValue,
) -> TractResult<Box<dyn OwnedDeviceTensor>>;
fn uninitialized_device_tensor(
&self,
shape: &[usize],
dt: DatumType,
) -> TractResult<Box<dyn OwnedDeviceTensor>>;
fn uninitialized_device_opaque_tensor(
&self,
opaque_fact: Box<dyn OpaqueFact>,
) -> TractResult<Box<dyn OwnedDeviceTensor>>;
fn synchronize(&self) -> TractResult<()>;
}Required Methods
fn tensor_to_device( &self, tensor: TValue, ) -> TractResult<Box<dyn OwnedDeviceTensor>>
fn uninitialized_device_tensor( &self, shape: &[usize], dt: DatumType, ) -> TractResult<Box<dyn OwnedDeviceTensor>>
fn uninitialized_device_opaque_tensor( &self, opaque_fact: Box<dyn OpaqueFact>, ) -> TractResult<Box<dyn OwnedDeviceTensor>>
fn synchronize(&self) -> TractResult<()>
Implementations
Sourceimpl dyn DeviceContext
impl dyn DeviceContext
Sourcepub fn is<__T: DeviceContext>(&self) -> bool
pub fn is<__T: DeviceContext>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: DeviceContext>(
self: Box<Self>,
) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: DeviceContext>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: DeviceContext>(
self: Rc<Self>,
) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: DeviceContext>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: DeviceContext>(&self) -> Option<&__T>
pub fn downcast_ref<__T: DeviceContext>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: DeviceContext>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: DeviceContext>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.