DeviceContext

Trait DeviceContext 

pub trait DeviceContext:
    Downcast
    + DynClone
    + Send
    + Sync {
    // Required methods
    fn buffer_from_slice(&self, tensor: &[u8]) -> Box<dyn DeviceBuffer>;
    fn synchronize(&self) -> TractResult<()>;
}

Required Methods

fn buffer_from_slice(&self, tensor: &[u8]) -> Box<dyn DeviceBuffer>

fn synchronize(&self) -> TractResult<()>

Implementations

Source

impl dyn DeviceContext

pub fn is<__T: DeviceContext>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: DeviceContext>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: DeviceContext>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: DeviceContext>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: DeviceContext>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

Implementors