pub enum DeviceTensor {
Owned(Box<dyn OwnedDeviceTensor>),
ArenaView(DeviceArenaView),
}Expand description
This struct represents a GPU tensor that can be either a owned tensor or an arena view.
Variants
Owned(Box<dyn OwnedDeviceTensor>)
ArenaView(DeviceArenaView)
Implementations
Sourceimpl DeviceTensor
impl DeviceTensor
pub const SUPPORTED_DT: [DatumType; 12]
pub fn tname(dt: DatumType) -> TractResult<&'static str>
Sourcepub fn uninitialized_dt(
dt: DatumType,
shape: &[usize],
) -> TractResult<DeviceTensor>
pub fn uninitialized_dt( dt: DatumType, shape: &[usize], ) -> TractResult<DeviceTensor>
Create an uninitialized DeviceTensor
pub fn uninitialized<T: Datum>(shape: &[usize]) -> TractResult<DeviceTensor>
pub fn from_shape<T: Copy + Datum>( shape: &[usize], data: &[T], ) -> TractResult<DeviceTensor>
pub fn is_supported_dt(dt: DatumType) -> bool
Sourcepub fn datum_type(&self) -> DatumType
pub fn datum_type(&self) -> DatumType
Get the datum type of the tensor.
Sourcepub fn device_buffer(&self) -> &dyn DeviceBuffer
pub fn device_buffer(&self) -> &dyn DeviceBuffer
Get underlying inner buffer.
Sourcepub fn buffer_offset<I: Copy + 'static>(&self) -> Iwhere
usize: AsPrimitive<I>,
pub fn buffer_offset<I: Copy + 'static>(&self) -> Iwhere
usize: AsPrimitive<I>,
Get underlying inner buffer offset
pub fn device_buffer_ptr(&self) -> *const c_void
Sourcepub fn view(&self) -> TensorView<'_>
pub fn view(&self) -> TensorView<'_>
Get underlying inner tensor view.
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Returns short description of the inner tensor.
Sourcepub fn reshaped(&self, shape: TVec<usize>) -> TractResult<Self>
pub fn reshaped(&self, shape: TVec<usize>) -> TractResult<Self>
Reshaped tensor with given shape.
pub fn restrided(&self, strides: TVec<isize>) -> TractResult<Self>
Sourcepub fn into_opaque_tensor(self) -> Tensor
pub fn into_opaque_tensor(self) -> Tensor
Convert device tensor to Opaque Tensor.
Sourcepub fn to_host(&self) -> TractResult<Arc<Tensor>>
pub fn to_host(&self) -> TractResult<Arc<Tensor>>
Synchronize the GPU Tensor by completing all current commands on GPU and returns the inner tensor.