pub trait OwnedDeviceTensor:
Downcast
+ DynClone
+ Send
+ Sync
+ Debug {
// Required methods
fn datum_type(&self) -> DatumType;
fn shape(&self) -> &[usize];
fn strides(&self) -> &[isize];
fn reshaped(&self, shape: TVec<usize>) -> TractResult<DeviceTensor>;
fn restrided(&self, shape: TVec<isize>) -> TractResult<DeviceTensor>;
fn opaque_fact(&self) -> Option<&dyn OpaqueFact>;
fn get_bytes_slice(&self, offset: usize, len: usize) -> Vec<u8> ⓘ;
fn device_buffer(&self) -> &dyn DeviceBuffer;
fn to_host(&self) -> TractResult<Arc<Tensor>>;
// Provided method
fn len(&self) -> usize { ... }
}Required Methods
fn datum_type(&self) -> DatumType
fn shape(&self) -> &[usize]
fn strides(&self) -> &[isize]
fn reshaped(&self, shape: TVec<usize>) -> TractResult<DeviceTensor>
fn restrided(&self, shape: TVec<isize>) -> TractResult<DeviceTensor>
fn opaque_fact(&self) -> Option<&dyn OpaqueFact>
fn get_bytes_slice(&self, offset: usize, len: usize) -> Vec<u8> ⓘ
fn device_buffer(&self) -> &dyn DeviceBuffer
fn to_host(&self) -> TractResult<Arc<Tensor>>
Provided Methods
Implementations
Sourceimpl dyn OwnedDeviceTensor
impl dyn OwnedDeviceTensor
Sourcepub fn is<__T: OwnedDeviceTensor>(&self) -> bool
pub fn is<__T: OwnedDeviceTensor>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: OwnedDeviceTensor>(
self: Box<Self>,
) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: OwnedDeviceTensor>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: OwnedDeviceTensor>(
self: Rc<Self>,
) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: OwnedDeviceTensor>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: OwnedDeviceTensor>(&self) -> Option<&__T>
pub fn downcast_ref<__T: OwnedDeviceTensor>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: OwnedDeviceTensor>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: OwnedDeviceTensor>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.